@@ -73,9 +73,6 @@ class SyncManager:
         self.syncWorkers = {}
         self.typeConverter = typeConverter
 
-        #Two way sync policy
-        self.policy = {"conflict":"skip","deleted":"skip"}
-
     def _cancel_sync_thread(self, cond):
         log.warn("Conduit already in queue (alive: %s)" % self.syncWorkers[cond].isAlive())
         #If the thread is alive then cancel it
@@ -90,23 +87,28 @@ class SyncManager:
             del(self.syncWorkers[cond])
 
     def _start_worker_thread(self, cond, worker):
+        log.info("Setting global cancel flag")
+        conduit.GLOBALS.cancelled = False
+
         log.debug("Starting worker: %s" % worker)
         cond.connect("sync-completed", self._on_sync_completed, worker)
         self.syncWorkers[cond] = worker
         self.syncWorkers[cond].start()
+        
+    def is_busy(self):
+        """
+        Returns true if any conduit is currently undergoing a sync
+        """
+        for cond in self.syncWorkers:
+            if self.syncWorkers[cond].isAlive():
+                return True
+        return False
 
     def sync_in_progress(self, cond):
         """
         Returns true if cond is currently undergoing sync, refresh etc
         """
-        return cond in self.syncWorkers
-
-    def set_twoway_policy(self, policy):
-        """
-        FIXME: Should be a per conduit setting
-        """
-        log.debug("Setting sync policy: %s" % policy)
-        self.policy = policy
+        return cond in self.syncWorkers and self.syncWorkers[cond].isAlive()
 
     def cancel_all(self):
         """
@@ -142,7 +144,7 @@ class SyncManager:
             log.info("Refresh already in progress")
             self.join_one(cond)
 
-        threadedWorker = SyncWorker(self.typeConverter, cond, False, self.policy)
+        threadedWorker = SyncWorker(self.typeConverter, cond, False)
         self._start_worker_thread(cond, threadedWorker)
 
     def sync_conduit(self, cond):
@@ -150,7 +152,7 @@ class SyncManager:
             log.info("Sync already in progress")
             self.join_one(cond)
 
-        threadedWorker = SyncWorker(self.typeConverter, cond, True, self.policy)
+        threadedWorker = SyncWorker(self.typeConverter, cond, True)
         self._start_worker_thread(cond, threadedWorker)
 
     def did_sync_abort(self, cond):
@@ -250,14 +252,13 @@ class SyncWorker(_ThreadedWorker):
     Operates on a per Conduit basis, so a single SyncWorker may synchronize
     one source with many sinks within a single conduit
     """
-    def __init__(self, typeConverter, cond, do_sync, policy):
+    def __init__(self, typeConverter, cond, do_sync):
         _ThreadedWorker.__init__(self)
         self.typeConverter = typeConverter
         self.cond = cond
         self.source = cond.datasource
         self.sinks = cond.datasinks
         self.do_sync = do_sync
-        self.policy = policy
 
         if self.cond.is_two_way():
             self.setName("%s <--> %s" % (self.source, self.sinks[0]))
@@ -276,20 +277,6 @@ class SyncWorker(_ThreadedWorker):
         except Exceptions.SyncronizeError, err:
             log.warn("%s\n%s" % (err, traceback.format_exc()))                     
             self.sinkErrors[sink] = DataProvider.STATUS_DONE_SYNC_ERROR
-            log.debug("ERROR GETTING DATA")
-        except Exceptions.SyncronizeFatalError, err:
-            log.warn("%s\n%s" % (err, traceback.format_exc()))
-            sink.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)                                  
-            source.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)                             
-            #Cannot continue
-            raise Exceptions.StopSync(self.state)                  
-        except Exception:       
-            #Cannot continue
-            log.critical("UNKNOWN SYNCHRONIZATION ERROR\n%s" % traceback.format_exc())
-            sink.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)
-            source.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)
-            raise Exceptions.StopSync(self.state)
-
         return data
 
     def _put_data(self, source, sink, sourceData, sourceDataRid):
@@ -300,6 +287,9 @@ class SyncWorker(_ThreadedWorker):
         if sourceData != None:
             try:
                 put_data(source, sink, sourceData, sourceDataRid, False)
+            except Exceptions.SyncronizeError, err:
+                log.warn("%s\n%s" % (err, traceback.format_exc()))                     
+                self.sinkErrors[sink] = DataProvider.STATUS_DONE_SYNC_ERROR
             except Exceptions.SynchronizeConflictError, err:
                 comp = err.comparison
                 if comp == COMPARISON_OLDER:
@@ -327,9 +317,7 @@ class SyncWorker(_ThreadedWorker):
             self.sinkErrors[sink] = DataProvider.STATUS_DONE_SYNC_ERROR
         except Exception:       
             log.critical("UNKNOWN CONVERSION ERROR\n%s" % traceback.format_exc())
-            sink.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)
-            source.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)
-            raise Exceptions.StopSync(self.state)
+            self.sinkErrors[sink] = DataProvider.STATUS_DONE_SYNC_ERROR
         return newdata
 
     def _apply_deleted_policy(self, sourceWrapper, sourceDataLUID, sinkWrapper, sinkDataLUID):
@@ -338,9 +326,9 @@ class SyncWorker(_ThreadedWorker):
         sourceDataLUID is the original UID of the data that has been deleted
         sinkDataLUID is the uid of the data in sink that should now be deleted
         """
-        if self.policy["deleted"] == "skip":
+        if self.cond.get_policy("deleted") == "skip":
             log.debug("Deleted Policy: Skipping")
-        elif self.policy["deleted"] == "ask":
+        elif self.cond.get_policy("deleted") == "ask":
             log.debug("Deleted Policy: Ask")
 
             #FIXME: Delete should be handled differently from conflict
@@ -371,7 +359,7 @@ class SyncWorker(_ThreadedWorker):
                     )
             self.cond.emit("sync-conflict", c)
 
-        elif self.policy["deleted"] == "replace":
+        elif self.cond.get_policy("deleted") == "replace":
             log.debug("Deleted Policy: Delete")
             #FIXME: Delete should be handled differently from conflict
             self.sinkErrors[sinkWrapper] = DataProvider.STATUS_DONE_SYNC_CONFLICT
@@ -383,9 +371,9 @@ class SyncWorker(_ThreadedWorker):
         the conflict up to the GUI or skipping altogether
         """
         if comparison == COMPARISON_EQUAL or comparison == COMPARISON_UNKNOWN or comparison == COMPARISON_OLDER:
-            if self.policy["conflict"] == "skip":
+            if self.cond.get_policy("conflict") == "skip":
                 log.debug("Conflict Policy: Skipping")
-            elif self.policy["conflict"] == "ask":
+            elif self.cond.get_policy("conflict") == "ask":
                 log.debug("Conflict Policy: Ask")
                 self.sinkErrors[sinkWrapper] = DataProvider.STATUS_DONE_SYNC_CONFLICT
 
@@ -407,7 +395,7 @@ class SyncWorker(_ThreadedWorker):
                         )
                 self.cond.emit("sync-conflict", c)
 
-            elif self.policy["conflict"] == "replace":
+            elif self.cond.get_policy("conflict") == "replace":
                 log.debug("Conflict Policy: Replace")
                 self.sinkErrors[sinkWrapper] = DataProvider.STATUS_DONE_SYNC_CONFLICT
 
@@ -618,13 +606,17 @@ class SyncWorker(_ThreadedWorker):
 
                 #Check dps have been configured
                 if self.state is self.CONFIGURE_STATE:
-                    if not self.source.module.is_configured():
+                    if not self.source.module.is_configured(
+                                                    isSource=True,
+                                                    isTwoWay=self.cond.is_two_way()):
                         self.source.module.set_status(DataProvider.STATUS_DONE_SYNC_NOT_CONFIGURED)
                         #Cannot continue if source not configured
                         raise Exceptions.StopSync(self.state)
         
                     for sink in self.sinks:
-                        if not sink.module.is_configured():
+                        if not sink.module.is_configured(
+                                                    isSource=False,
+                                                    isTwoWay=self.cond.is_two_way()):
                             sinkDidntConfigureOK[sink] = True
                             self.sinkErrors[sink] = DataProvider.STATUS_DONE_SYNC_NOT_CONFIGURED
                     #Need to have at least one successfully configured sink
@@ -691,15 +683,28 @@ class SyncWorker(_ThreadedWorker):
                         self.check_thread_not_cancelled([self.source, sink])
                         #only sync with those sinks that refresh'd OK
                         if sink not in sinkDidntRefreshOK:
-                            #now perform a one or two way sync depending on the user prefs
-                            #and the capabilities of the dataprovider
-                            if  self.cond.is_two_way():
-                                #two way
-                                self.two_way_sync(self.source, sink)
-                            else:
-                                #one way
-                                self.one_way_sync(self.source, sink)
-     
+                            try:
+                                #now perform a one or two way sync depending on the user prefs
+                                #and the capabilities of the dataprovider
+                                if  self.cond.is_two_way():
+                                    #two way
+                                    self.two_way_sync(self.source, sink)
+                                else:
+                                    #one way
+                                    self.one_way_sync(self.source, sink)
+                            except Exceptions.SyncronizeFatalError, err:
+                                log.warn("%s\n%s" % (err, traceback.format_exc()))
+                                sink.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)                                  
+                                self.source.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)                             
+                                #cannot continue with this source, sink pair
+                                continue
+                            except Exception:       
+                                log.critical("UNKNOWN SYNCHRONIZATION ERROR\n%s" % traceback.format_exc())
+                                sink.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)
+                                self.source.module.set_status(DataProvider.STATUS_DONE_SYNC_ERROR)
+                                #cannot continue with this source, sink pair
+                                continue
+
                     #Done go clean up
                     self.state = self.DONE_STATE
 
@@ -767,7 +772,9 @@ class RefreshDataProviderWorker(_ThreadedWorker):
             log.debug("Refresh %s beginning" % self)
             self.cond.emit("sync-started")
 
-            if not self.dataproviderWrapper.module.is_configured():
+            if not self.dataproviderWrapper.module.is_configured(
+                                                isSource=self.cond.get_dataprovider_position(self.dataproviderWrapper)[0]==0,
+                                                isTwoWay=self.cond.is_two_way()):
                 self.dataproviderWrapper.module.set_status(DataProvider.STATUS_DONE_SYNC_NOT_CONFIGURED)
                 #Cannot continue if source not configured
                 raise Exceptions.StopSync(self.state)
