@@ -14,6 +14,9 @@ import conduit
 import conduit.datatypes.DataType as DataType
 import conduit.Vfs as Vfs
 
+class FileTransferError(Exception):
+    pass
+
 class File(DataType.DataType):
     
     _name_ = "file"
@@ -35,9 +38,6 @@ class File(DataType.DataType):
         #optional args
         self.basePath = kwargs.get("basepath","")
         self.group = kwargs.get("group","")
-        
-        #calculate the relative path
-        self.relpath = self._get_text_uri().replace(self.basePath,"")
 
         #instance
         self.fileInfo = None
@@ -167,7 +167,6 @@ class File(DataType.DataType):
         self.URI = f.URI
         self.basePath = f.basePath
         self.group = f.group
-        self.relpath = f.relpath
         self.fileInfo = f.fileInfo
         self.fileExists = f.fileExists
         self.triedOpen = f.triedOpen
@@ -300,15 +299,18 @@ class File(DataType.DataType):
             Vfs.uri_make_directory_and_parents(parent)
 
         #Copy the file
-        result = gnomevfs.xfer_uri(
-                    source_uri=self.URI,
-                    target_uri=newURI,
-                    xfer_options=gnomevfs.XFER_NEW_UNIQUE_DIRECTORY,
-                    error_mode=gnomevfs.XFER_ERROR_MODE_ABORT,
-                    overwrite_mode=mode,
-                    progress_callback=self._xfer_progress_callback,
-                    data=cancel_function
-                    )
+        try:        
+            result = gnomevfs.xfer_uri(
+                        source_uri=self.URI,
+                        target_uri=newURI,
+                        xfer_options=gnomevfs.XFER_NEW_UNIQUE_DIRECTORY,
+                        error_mode=gnomevfs.XFER_ERROR_MODE_ABORT,
+                        overwrite_mode=mode,
+                        progress_callback=self._xfer_progress_callback,
+                        data=cancel_function
+                        )
+        except gnomevfs.InterruptedError:
+            raise FileTransferError
 
         #close the file and the handle so that the file info is refreshed
         self.URI = newURI
@@ -416,6 +418,12 @@ class File(DataType.DataType):
             return u
         else:
             return self.to_tempfile()
+            
+    def get_relative_uri(self):
+        """
+        @returns: The files URI relative to its basepath
+        """
+        return self._get_text_uri().replace(self.basePath,"")
 
     def compare(self, B, sizeOnly=False, existOnly=False):
         """
@@ -480,7 +488,6 @@ class File(DataType.DataType):
         data = DataType.DataType.__getstate__(self)
         data['basePath'] = self.basePath
         data['group'] = self.group
-        data['relpath'] = self.relpath
         data['filename'] = self.get_filename()
         data['filemtime'] = self.get_mtime()
 
@@ -497,7 +504,6 @@ class File(DataType.DataType):
         self.URI = gnomevfs.URI(name)
         self.basePath = data['basePath']
         self.group = data['group']
-        self.relpath = data['relpath']
         self._defer_rename(data['filename'])
         self._defer_new_mtime(data['filemtime'])
 
