@@ -15,8 +15,8 @@ import logging
 log = logging.getLogger("gtkui.Canvas")
 
 import conduit
-from conduit.Conduit import Conduit
-from conduit.gtkui.Tree import DND_TARGETS
+import conduit.Conduit as Conduit
+import conduit.gtkui.Tree
 
 #Tango colors taken from 
 #http://tango.freedesktop.org/Tango_Icon_Theme_Guidelines
@@ -61,18 +61,21 @@ class Canvas(goocanvas.Canvas):
     """
     This class manages many objects
     """
-    CANVAS_WIDTH = 450
-    CANVAS_HEIGHT = 450
-    WELCOME_MESSAGE = _("Drag a Dataprovider here to continue")
-
+    WELCOME_MESSAGE = _("Drag a Data Provider here to continue")
     def __init__(self, parentWindow, typeConverter, syncManager, dataproviderMenu, conduitMenu):
         """
         Draws an empty canvas of the appropriate size
         """
         #setup the canvas
         goocanvas.Canvas.__init__(self)
-        self.set_bounds(0, 0, Canvas.CANVAS_WIDTH, Canvas.CANVAS_HEIGHT)
-        self.set_size_request(Canvas.CANVAS_WIDTH, Canvas.CANVAS_HEIGHT)
+        self.set_bounds(0, 0, 
+                conduit.GLOBALS.settings.get("gui_initial_canvas_width"),
+                conduit.GLOBALS.settings.get("gui_initial_canvas_height")
+                )
+        self.set_size_request(
+                conduit.GLOBALS.settings.get("gui_initial_canvas_width"),
+                conduit.GLOBALS.settings.get("gui_initial_canvas_height")
+                )
         self.root = self.get_root_item()
 
         self.sync_manager = syncManager
@@ -83,7 +86,7 @@ class Canvas(goocanvas.Canvas):
 
         #set up DND from the treeview
         self.drag_dest_set(  gtk.gdk.BUTTON1_MASK | gtk.gdk.BUTTON3_MASK,
-                        DND_TARGETS,
+                        conduit.gtkui.Tree.DND_TARGETS,
                         gtk.gdk.ACTION_COPY | gtk.gdk.ACTION_LINK)
         self.connect('drag-motion', self.on_drag_motion)
         self.connect('size-allocate', self._canvas_resized)
@@ -174,6 +177,14 @@ class Canvas(goocanvas.Canvas):
                 self.twoWayMenuItem.set_active(self.selectedConduitItem.model.is_two_way())
                 #Set item ticked if two way sync enabled
                 self.slowSyncMenuItem.set_active(self.selectedConduitItem.model.slowSyncEnabled)
+                #Set item ticked if two way sync enabled
+                self.autoSyncMenuItem.set_active(self.selectedConduitItem.model.autoSyncEnabled)
+                #Set the conflict and delete policy
+                for policyName in Conduit.CONFLICT_POLICY_NAMES:
+                    policyValue = self.selectedConduitItem.model.get_policy(policyName)
+                    widgetName = "%s_%s" % (policyName,policyValue)
+                    self.policyWidgets[widgetName].set_active(True)
+
                 #Show the menu                
                 if not self.selectedConduitItem.model.is_busy():
                     self.conduitMenu.popup(
@@ -355,11 +366,23 @@ class Canvas(goocanvas.Canvas):
         self.slowSyncMenuItem = conduitPopupXML.get_widget("slow_sync")
         self.slowSyncMenuItem.connect("toggled", self.on_slow_sync_toggle)
 
+        self.autoSyncMenuItem = conduitPopupXML.get_widget("auto_sync")
+        self.autoSyncMenuItem.connect("toggled", self.on_auto_sync_toggle)
+
+        #connect the conflict popups
+        self.policyWidgets = {}
+        for policyName in Conduit.CONFLICT_POLICY_NAMES:
+            for policyValue in Conduit.CONFLICT_POLICY_VALUES:
+                widgetName = "%s_%s" % (policyName,policyValue)
+                #store the widget and connect to toggled signal
+                widget = conduitPopupXML.get_widget(widgetName)
+                widget.connect("toggled", self.on_policy_toggle, policyName, policyValue)
+                self.policyWidgets[widgetName] = widget
+                
         #connect the menu callbacks
         conduitPopupXML.signal_autoconnect(self)
         dataproviderPopupXML.signal_autoconnect(self)        
 
-
     def on_delete_conduit_clicked(self, widget):
         """
         Delete a conduit and all its associated dataproviders
@@ -397,6 +420,7 @@ class Canvas(goocanvas.Canvas):
         log.info("Configuring %s" % dp)
         #May block
         dp.configure(self.parentWindow)
+        self.selectedDataproviderItem.update_appearance()
 
     def on_refresh_dataprovider_clicked(self, widget):
         """
@@ -425,6 +449,19 @@ class Canvas(goocanvas.Canvas):
         else:
             self.selectedConduitItem.model.disable_slow_sync()
 
+    def on_auto_sync_toggle(self, widget):
+        """
+        Enables or disables slow sync of dataproviders.
+        """
+        if widget.get_active():
+            self.selectedConduitItem.model.enable_auto_sync()
+        else:
+            self.selectedConduitItem.model.disable_auto_sync()
+
+    def on_policy_toggle(self, widget, policyName, policyValue):
+        if widget.get_active():
+            self.selectedConduitItem.model.set_policy(policyName, policyValue)
+
     def add_dataprovider_to_canvas(self, key, dataproviderWrapper, x, y):
         """
         Adds a new dataprovider to the Canvas
@@ -447,7 +484,7 @@ class Canvas(goocanvas.Canvas):
             trySourceFirst = False
 
         if existing == None:
-            cond = Conduit(self.sync_manager)
+            cond = Conduit.Conduit(self.sync_manager)
             cond.add_dataprovider(dataproviderWrapper, trySourceFirst)
             self.model.add_conduit(cond)
 
@@ -550,23 +587,6 @@ class DataProviderCanvasItem(_CanvasItem):
             else:
                 log.warn("Unknown module type: Cannot get fill color")
 
-    def _update_appearance(self):
-        #the image
-        pb = self._get_icon()
-        pbx = int((1*self.WIDGET_WIDTH/5) - (pb.get_width()/2))
-        pby = int((1*self.WIDGET_HEIGHT/3) - (pb.get_height()/2))
-        self.image.set_property("pixbuf",pb)
-
-        self.name.set_property("text",self.model.get_name())
-
-        if self.model.module == None:
-            statusText = self.PENDING_MESSAGE
-        else:
-            statusText = self.model.module.get_status_text()
-        self.statusText.set_property("text",statusText)
-
-        self.box.set_property("fill_color_rgba",self._get_fill_color())
-
     def _get_icon(self):
         return self.model.get_icon()        
 
@@ -619,10 +639,27 @@ class DataProviderCanvasItem(_CanvasItem):
     def _on_status_changed(self, dataprovider):
         msg = dataprovider.get_status_text()
         self.statusText.set_property("text", msg)
+        
+    def update_appearance(self):
+        #the image
+        pb = self._get_icon()
+        pbx = int((1*self.WIDGET_WIDTH/5) - (pb.get_width()/2))
+        pby = int((1*self.WIDGET_HEIGHT/3) - (pb.get_height()/2))
+        self.image.set_property("pixbuf",pb)
+
+        self.name.set_property("text",self.model.get_name())
+
+        if self.model.module == None:
+            statusText = self.PENDING_MESSAGE
+        else:
+            statusText = self.model.module.get_status_text()
+        self.statusText.set_property("text",statusText)
+
+        self.box.set_property("fill_color_rgba",self._get_fill_color())
 
     def set_model(self, model):
         self.model = model
-        self._update_appearance()
+        self.update_appearance()
         if self.model.module != None:
             self.model.module.connect("change-detected", self._on_change_detected)
             self.model.module.connect("status-changed", self._on_status_changed)
@@ -741,9 +778,7 @@ class ConduitCanvasItem(_CanvasItem):
         except KeyError: pass
 
     def _on_conduit_parameters_changed(self, cond):
-        #update the twowayness of the connectors
-        for c in self.connectorItems.values():
-            c.set_two_way(self.model.is_two_way())
+        self.update_appearance()
 
     def _on_conduit_dataprovider_changed(self, cond, olddpw, newdpw):
         for item in [self.sourceItem] + self.sinkDpItems:
@@ -794,6 +829,11 @@ class ConduitCanvasItem(_CanvasItem):
                         break
 
 
+    def update_appearance(self):
+        #update the twowayness of the connectors
+        for c in self.connectorItems.values():
+            c.set_two_way(self.model.is_two_way())
+
     def add_dataprovider_canvas_item(self, item):
         self._position_dataprovider(item)
 
